@@ -62,8 +62,8 @@ def tplot(name,
           window_name='Plot',
           interactive=False,
           # the following are for the matplotlib version
-          xsize=8, 
-          ysize=10, 
+          xsize=None,
+          ysize=None,
           save_eps='', 
           save_svg='', 
           save_pdf='',
